==> openshift-model-miscellaneous-5.12.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/EgressRouterBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EgressRouterBuilder extends io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouterFluentImpl<io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouterBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouter,io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouterBuilder>{
  public EgressRouterBuilder() {
    this(false);
  }
  public EgressRouterBuilder(java.lang.Boolean validationEnabled) {
    this(new EgressRouter(), validationEnabled);
  }
  public EgressRouterBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouterFluent<?> fluent) {
    this(fluent, false);
  }
  public EgressRouterBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouterFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new EgressRouter(), validationEnabled);
  }
  public EgressRouterBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouterFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouter instance) {
    this(fluent, instance, false);
  }
  public EgressRouterBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouterFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouter instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public EgressRouterBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouter instance) {
    this(instance,false);
  }
  public EgressRouterBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouter instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouterFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.EgressRouter build() {
    EgressRouter buildable = new EgressRouter(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EgressRouterBuilder that = (EgressRouterBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.6.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/EgressRouterBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EgressRouterBuilder extends EgressRouterFluentImpl<EgressRouterBuilder> implements VisitableBuilder<EgressRouter,EgressRouterBuilder>{
  public EgressRouterBuilder() {
    this(false);
  }
  public EgressRouterBuilder(Boolean validationEnabled) {
    this(new EgressRouter(), validationEnabled);
  }
  public EgressRouterBuilder(EgressRouterFluent<?> fluent) {
    this(fluent, false);
  }
  public EgressRouterBuilder(EgressRouterFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EgressRouter(), validationEnabled);
  }
  public EgressRouterBuilder(EgressRouterFluent<?> fluent,EgressRouter instance) {
    this(fluent, instance, false);
  }
  public EgressRouterBuilder(EgressRouterFluent<?> fluent,EgressRouter instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public EgressRouterBuilder(EgressRouter instance) {
    this(instance,false);
  }
  public EgressRouterBuilder(EgressRouter instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  EgressRouterFluent<?> fluent;
  Boolean validationEnabled;
  public EgressRouter build() {
    EgressRouter buildable = new EgressRouter(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
